HIRISE_api.preprocessing.Dimension_Reduction — HIRISE_api documentation

# HIRISE_api.preprocessing.Dimension_Reduction

Functions

`PCA_analysis`(encoded_samples, labels[, ...]) | The PCA analysis allows the user to understand diffrent aspects of the PCA mehod.
`TSNE_analysis`(encoded_samples, labels[, ...]) | The T-SNE analysis allows the user to understand diffrent aspects of the TSNE method. The user can choose to plot the 2D and 3D visualisations.
`UMAP_analysis`(encoded_samples[, components, ...]) | The UMAP analysis allows the user to understand diffrent aspects of the UMAP method.